/* ======================================================================*
*     ____ _    __   ____      __       _____                            * 
*    / __ \ |  / /  /  _/___  / /____  / / (_)___ ____  ____  ________   *
*   / /_/ / | / /   / // __ \/ __/ _ \/ / / / __ `/ _ \/ __ \/ ___/ _ \  *
*  / _, _/| |/ /  _/ // / / / /_/  __/ / / / /_/ /  __/ / / / /__/  __/  *
* /_/ |_| |___/  /___/_/ /_/\__/\___/_/_/_/\__, /\___/_/ /_/\___/\___/   *
*                                        /____/                          *
* Copyright RV Intelligence, © 2020                                      *
* All Rights Reserved                                                    *
* UNPUBLISHED, LICENSED SOFTWARE.                                        *
*                                                                        *
* CONFIDENTIAL AND PROPRIETARY INFORMATION                               *
* WHICH IS THE PROPERTY OF RV INTELLIGENCE                               *
* Herbert Gingold / Mark McCorkle                                        *
*========================================================================*/

#include "main.h"
#include "accel_bma253.h"

/*******************************************************************************
* Function Name: main()
********************************************************************************
*
* Summary:
* The function configures and starts BLE component. Also, it tracks trigger
* event (button press) and switches to bootloader application.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
int main()
{
    CyGlobalIntEnable;

/* For GCC compiler use separate API to initialize BLE Stack SRAM.
     * This is required for code sharing.
     */
#if !defined(__ARMCC_VERSION)
    InitializeBootloaderSRAM();
#endif

    PrintProjectHeader();

    /* Checks if Self Project Image is updated and Runs for the First time */
    AfterImageUpdate();

    CyBle_Start(AppCallBack);

    DBG_PRINTF("Starting WDT, status: %x \r\n", apiResult);
    WDT_Start();

    DBG_PRINTF("Performing battery test, status: %x \r\n", apiResult);
    battery_test();

    DBG_PRINTF("Starting SPI, status: %x \r\n", apiResult);
   // SPI_Start();

   // apiResult = AccelCheckName();

    DBG_PRINTF("Accell config, status: %x \r\n", apiResult);
   // AccelConfig();
   Accel_Pwr_Control_Write(0);

    while (1)
    {
       /* Call ProcessEvents API each connection interval */
        CyBle_ProcessEvents();

        
        if (CyBle_GetState() != CYBLE_STATE_INITIALIZING)
        {
            /* Request BLE subsystem to enter into Deep-Sleep mode between connection and advertising intervals */
            lpMode = CyBle_EnterLPM(CYBLE_BLESS_DEEPSLEEP);
            /* Disable global interrupts */
            //CyGlobalIntDisable;
            /* Get current BLE subsystem state */
            blessState = CyBle_GetBleSsState();

            /* When BLE subsystem has been put into Deep-Sleep mode */
            if (lpMode == CYBLE_BLESS_DEEPSLEEP)
            {
                /* And it is still there or ECO is on */
                if (blessState == CYBLE_BLESS_STATE_ECO_ON || blessState == CYBLE_BLESS_STATE_DEEPSLEEP)
                {
                    
                    //isr_WDT_Disable();
                    //WDT_Stop();
//                    isr_NewData_Disable();
//                    SPI_Stop();
//                    Accel_Pwr_Control_Write(0);
                    
                    
                    DBG_PRINTF("\r\n Entering Deep Sleep \r\n");
                    /* Put the CPU into the Deep-Sleep mode */
                    CySysPmDeepSleep();
                    DBG_PRINTF("\r\n Exiting Deep Sleep \r\n");
                    /* Handle advertising led blinking */
                    
                    
//                    Accel_Pwr_Control_Write(0);
//                    SPI_Start();
//                    isr_NewData_Enable();
                    //isr_WDT_Enable();
                    //WDT_Start();
                    
                }
            }
            else /* When BLE subsystem has been put into Sleep mode or is active */
            {
                lpMode = CyBle_EnterLPM(CYBLE_BLESS_SLEEP);

                blessState = CyBle_GetBleSsState();
                if(lpMode == CYBLE_BLESS_SLEEP)
                {
                    if (blessState != CYBLE_BLESS_STATE_EVENT_CLOSE)
                    {
                        //CySysClkWriteEcoDiv(CY_SYS_CLK_ECO_DIV8);
                        DBG_PRINTF("\r\n Entering Sleep \r\n");
                        CySysPmSleep();
                        DBG_PRINTF("\r\n Exiting Sleep \r\n");
                        //CySysClkWriteEcoDiv(CY_SYS_CLK_ECO_DIV1);
                    }
                }
            }
            /* Enable global interrupt */
            //CyGlobalIntEnable;
            
        /* Call ProcessEvents API each connection interval */
        CyBle_ProcessEvents();

            
        }

        if (CyBle_GetState() == CYBLE_STATE_CONNECTED)
        {

            /* Store bonding data to flash only when all debug information has been sent */
#if (CYBLE_BONDING_REQUIREMENT == CYBLE_BONDING_YES)
            if ((cyBle_pendingFlashWrite != 0u))
            {
#if (DEBUG_UART_ENABLED == YES)
                apiResult = CyBle_StoreBondingData(0u);
                DBG_PRINTF("Store bonding data, status: %x \r\n", apiResult);
                (void)apiResult;
#else
                (void)CyBle_StoreBondingData(0u);
#endif /* (DEBUG_UART_ENABLED == YES) */
            }
#endif /* CYBLE_BONDING_REQUIREMENT == CYBLE_BONDING_YES */
        }

        // new data is ready to process
        if (newDataFlag)
        {
            AccelGetData();
            AccelProcessData();
            newDataFlag = FALSE;
        }

 
        //HandleLeds();

        /* If key press event was detected - debounce it and switch to bootloader emulator mode */
        if (bootloaderFlag == 1)
        {
#if (DEBUG_UART_ENABLED == YES)
            DBG_PRINTF("Switching to BLE Upgradable Stack Example Stack project.\r\n");
            CyDelay(500);
#endif /* (DEBUG_UART_ENABLED == YES) */

            Bootloadable_SetActiveApplication(0);
            Bootloadable_Load();
            CySoftwareReset();
        }
    }
}

/* [] END OF FILE */
